Recipes
=======

.. toctree::
   :maxdepth: 1

   drop-empty-tags/index
   insert-wrapping-element/index
   adding-an-attribute/index
   modifying-an-attribute/index
   modifying-text/index
   create-list-from-anchors/index

Contributing a recipe
---------------------

Each recipe lives in a folder under ``docs/recipes`` and follows a standard
format that facilitates automated testing, ensuring each recipe works as
advertised.
